PALM-meteo: palmmeteo/plugins.py File Reference

PALM-meteo

Classes | Namespaces | Functions | Variables
plugins.py File Reference

## Classes
class | palmmeteo.plugins.PluginMeta
class | palmmeteo.plugins.Plugin
class | palmmeteo.plugins.ImportPluginMixin
class | palmmeteo.plugins.HInterpPluginMixin
class | palmmeteo.plugins.VInterpPluginMixin
class | palmmeteo.plugins.SetupPluginMixin
class | palmmeteo.plugins.WritePluginMixin

## Namespaces
namespace | palmmeteo
namespace | palmmeteo.plugins

## Functions
def | palmmeteo.plugins.eventhandler (event)
def | palmmeteo.plugins.plugin_factory (plugin, *args, **kwargs)

## Variables
dictionary | palmmeteo.plugins.event_hooks
list | palmmeteo.plugins.plugins = []